linchpin.api
============

.. automodule:: linchpin.api

   
   
   .. rubric:: Functions

   .. autosummary::
   
      namedtuple
      yaml2json
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      DataLoader
      Inventory
      LinchpinAPI
      LinchpinHooks
      PlaybookCallback
      PlaybookExecutor
      State
      VariableManager
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      LinchpinError
   
   